Put all versions of AIzyme_Functions here. The most up to date version is AIzyme_Functions_009

Every version should be clearly labeled with a number. Lets track major changes in here.

| Version | Changes |
|----------|----------|
| AIzymes_009 | First uploaded version. <br> Adjusted catalytic score, now uses 6-3-2 weights <br> Added extra rows to all_scores.csv to keep track of scores from design and relax run seperately. <br> Aligned ESMFold Structure after relaxing for PreMatchRelax.|
| AIzymes_010 | Incorporated ProteinMPNN.|
